import { Box, Skeleton } from '@rocket.chat/fuselage';
import type { FC } from 'react';
import React, { useMemo } from 'react';

import { AsyncStatePhase } from '../../../hooks/useAsyncState';
import { useEndpointData } from '../../../hooks/useEndpointData';
import EditRoom from './EditRoom';

const EditRoomWithData: FC<{ rid?: string; onReload: () => void }> = ({ rid, onReload }) => {
	const {
		value: data,
		phase: state,
		error,
		reload,
	} = useEndpointData('/v1/rooms.adminRooms.getRoom', { params: useMemo(() => ({ rid }), [rid]) });

	if (state === AsyncStatePhase.LOADING) {
		return (
			<Box w='full' p='x24'>
				<Skeleton mbe='x4' />
				<Skeleton mbe='x8' />
				<Skeleton mbe='x4' />
				<Skeleton mbe='x8' />
				<Skeleton mbe='x4' />
				<Skeleton mbe='x8' />
			</Box>
		);
	}

	if (state === AsyncStatePhase.REJECTED) {
		return <>{error?.message}</>;
	}

	const handleChange = (): void => {
		reload();
		onReload();
	};

	const handleDelete = (): void => {
		onReload();
	};

	return data ? <EditRoom room={data} onChange={handleChange} onDelete={handleDelete} /> : null;
};

export default EditRoomWithData;
